@@ -1,7 +1,7 @@
 console.log("Input script loaded");
 
 $(document).ready(function () {
-    let all_inputs = $(".input-group input");
+    let all_inputs = $(".split-input-group input");
     console.log("Split inputs loaded.")
     if (!window.clear_split_inputs) {
         console.log("Split inputs won't be cleared.")
@@ -20,4 +20,4 @@ $(document).ready(function () {
             console.log("Next target selected");
         }
     })
-})
\ No newline at end of file
+})
